@@ -30,7 +30,7 @@
 
 """pSock is a socket / threading module that helps developers and students to approach Server-Client creation and much more."""
 
-import socket, threading, socketserver
+import socket, threading
 
 # FAMILY ADDRESS
 
@@ -181,7 +181,9 @@ class pSock:
         self.sock.close()
         self.connection = False
 
-    socket.dup
+    @property
+    def gethostname(self):
+        return socket.gethostname()
 
     @property
     def getactiveconnectionsdata(self):
